==> zeusmp1.5.10.tar.gz: zeusmp/exe/mpiwrap.pl <==
#!/usr/bin/perl -w
use strict;

#wrapper script for mpi version of zeus
#also it will attempt to restart from most resent restart dump
#so if you are starting a new run, there must be 
#NO old restart files in the directory
#7/20/04 jcv
#updated to figure out the correct number of processors from zmp_inp file
#Checks to make sure restart dumps are all the same size
#This doesn't insure they are good, but it is a simple test
#Checks to makes sure number of restart dumps matches processor number
#10/26/04 jcv

my $hostfile="lamhosts";
my $nprocessors;
my $executable="zeusmp.x";
my $logfile=$executable."_output.txt";
my $log2="zmp_log";

&log_rotate;
$nprocessors=&guess_nprocessors;
&check_restarts;
&set_restart;
&run;

sub log_rotate{
    my @logs=glob "$logfile*";
    my $new=$#logs+1;
    if(-e $logfile){
	rename "$logfile","$logfile.$new";
    }
    if(-e $log2){
      rename "$log2","$log2.$new";
    }
}

sub guess_nprocessors{
    my $file="zmp_inp";
    open DATA, "< $file" or die("cannot open $file: $!");
    my @data=<DATA>;
    close DATA;
    chomp(@data);
    my @mpi_line;
    my @ntiles;
    my $procs=1;
    foreach(@data){
	if($_=~"ntiles"){
	    @mpi_line=split /,/, $_;
	}
    }
    foreach(@mpi_line){
	if($_=~"ntiles"){
	    @ntiles=split//,$_;
	    $procs=$ntiles[$#ntiles]*$procs;
	}
    }
    return $procs;
}

sub check_restarts{
    my @restarts=glob "resaa*.*";
    my @sizes;
    my $i=0;
    if(@restarts){
	foreach(@restarts){
	    $sizes[$i]= -s $_;
	    $i++;
	}
    }
    if(($i != 0) && ($i != $nprocessors) && ($i != 2*$nprocessors)){
	die "Number of restart dumps do not match number of processors.\n";
    }
    for($i=0;$i<$#sizes;$i++){
	if($sizes[$i] != $sizes[$i+1]){
	    die "Restart dumps are not the same size. Aborting.\n";
	}
    }
}

sub set_restart{
    my @restarts=glob "resaa000000.*";
    my $restart="resaa000000.000";
    my $irestart=0;
    my $file;
    my @age;
    my $i=0;
    my $youngest;
    my $youngesti;
    if(@restarts){
	$irestart=1;
	foreach $file (@restarts){
	    $age[$i]=-M $file;
	    if($i==0){
		$youngest=$age[$i];
		$youngesti=$i;
	    }else{
		if($age[$i]<$youngest){
		    $youngest=$age[$i];
		    $youngesti=$i;
		}
	    }
	    $i++;
	}
	$restart=$restarts[$youngesti];
    }

    @ARGV=qw#zmp_inp#;
    $^I="~";
    my $resline;
    my @resline;
    my $restartline;
    while(<>){
	if($_=~/rescon/){
	    $resline=$_;
	    @resline=split/,/,$resline;
	    if($resline[1]){
		$restartline="rescon irestart=$irestart,$resline[1],resfile='$restart' \$";
	    }else{
		$restartline="rescon irestart=0 \$";
	    }
	    s/rescon.*/$restartline/;
	}
	print;
    }
}

sub run{
    system "lamboot -v $hostfile >& mpioutput.txt";
    system "mpirun -v -np $nprocessors $executable >& $logfile";
    system "wipe -v $hostfile >& mpioutput.txt";
}

==> zeusmp1.5.13.tar.gz: zeusmp/exe/mpiwrap.pl <==
#!/usr/bin/perl -w
use strict;
use Sys::Hostname;

#wrapper script for zeusmp v1.5
#also it will attempt to restart from most resent restart dump
#so if you are starting a new run, there must be 
#NO old restart files in the directory
#7/20/04 jcv
#updated to figure out the correct number of processors from zmp_inp file
#Checks to make sure restart dumps are all the same size
#This doesn't insure they are good, but it is a simple test
#Checks to makes sure number of restart dumps matches processor number
#10/26/04 jcv
#Added a little check so that lamboot is not run on deepthought.umd.edu
#since that uses PBS for submissions and it is better to do that in 
#submit script, but I still want the rest of what this does.
#01/26/07 jcv
#Modified to pass cmd line options to mpirun for PBS
#01/29/07 jcv

my $hostfile="lamhosts";
my $nprocessors;
my $executable="zeusmp.x";
my $logfile=$executable."_output.txt";
my $log2="zmp_log";
my $host=hostname;
my $cmdline="";

if (@ARGV){
    foreach (@ARGV){
	$cmdline=$cmdline." ".$_;
    }
}

&log_rotate;
$nprocessors=&guess_nprocessors;
&check_restarts;
&set_restart;
&run;

sub log_rotate{
    my @logs=glob "$logfile*";
    my $new=$#logs+1;
    if(-e $logfile){
	rename "$logfile","$logfile.$new";
    }
    if(-e $log2){
      rename "$log2","$log2.$new";
    }
}

sub guess_nprocessors{
    my $file="zmp_inp";
    open DATA, "< $file" or die("cannot open $file: $!");
    my @data=<DATA>;
    close DATA;
    chomp(@data);
    my @mpi_line;
    my @ntiles;
    my $procs=1;
    foreach(@data){
	if($_=~"ntiles"){
	    @mpi_line=split /,/, $_;
	}
    }
    foreach(@mpi_line){
	if($_=~"ntiles"){
	    @ntiles=split//,$_;
	    $procs=$ntiles[$#ntiles]*$procs;
	}
    }
    return $procs;
}

sub check_restarts{
    my @restarts=glob "resaa*.*";
    my @sizes;
    my $i=0;
    if(@restarts){
	foreach(@restarts){
	    $sizes[$i]= -s $_;
	    $i++;
	}
    }
    if(($i != 0) && ($i != $nprocessors) && ($i != 2*$nprocessors)){
	die "Number of restart dumps do not match number of processors.\n";
    }
    for($i=0;$i<$#sizes;$i++){
	if($sizes[$i] != $sizes[$i+1]){
	    die "Restart dumps are not the same size. Aborting.\n";
	}
    }
}

sub set_restart{
    my @restarts=glob "resaa000000.*";
    my $restart="resaa000000.000";
    my $irestart=0;
    my $file;
    my @age;
    my $i=0;
    my $youngest;
    my $youngesti;
    if(@restarts){
	$irestart=1;
	foreach $file (@restarts){
	    $age[$i]=-M $file;
	    if($i==0){
		$youngest=$age[$i];
		$youngesti=$i;
	    }else{
		if($age[$i]<$youngest){
		    $youngest=$age[$i];
		    $youngesti=$i;
		}
	    }
	    $i++;
	}
	$restart=$restarts[$youngesti];
    }

    @ARGV=qw#zmp_inp#;
    $^I="~";
    my $resline;
    my @resline;
    my $restartline;
    while(<>){
	if($_=~/rescon/){
	    $resline=$_;
	    @resline=split/,/,$resline;
	    if($resline[1]){
		$restartline="rescon irestart=$irestart,$resline[1],resfile='$restart' /\$";
	    }else{
		$restartline="rescon irestart=0 \$";
	    }
	    s/rescon.*/$restartline/;
	}
	print;
    }
}

sub run{
    unless($host=~"deepthought"){
	system "lamboot -v $hostfile >& mpioutput.txt";
    }
    system "mpirun $cmdline -v -np $nprocessors $executable >& $logfile";
    unless($host=~"deepthought"){
	system "wipe -v $hostfile >& mpioutput.txt";
    }
}
